@@ -4,9 +4,8 @@ use 5.007003;
 use strict;
 use warnings;
 
-use Data::Dumper;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 NAME
 
@@ -46,6 +45,7 @@ Version 0.11
      $acme->authz( $domain );
      $acme->handle_challenge( $challenges->{$domain} );
      $acme->check_challenge();
+     $acme->cleanup_challenge( $challenges->{$domain} );
    }
 
    my $cert = $acme->sign( $csr_file );
@@ -238,6 +238,10 @@ challenge.
 Called after C<handle_challenge>.  This will poll the challenge status
 resource and will return when the state changes from 'pending'.
 
+=item cleanup_challenge()
+
+Called after C<check_challenge> to remove the challenge files.
+
 =item $cert = sign( $csr_filename )
 
 =item $cert = sign( \$buffer )
@@ -362,8 +366,9 @@ sub _init
 
   $self->{log} = $args->{'logger'} || do
   {
-    require Protocol::ACME::Logger;
-    Protocol::ACME::Logger->new($self->{loglevel});
+      require Log::Any::Adapter;
+      Log::Any::Adapter->set('+Protocol::ACME::Logger', log_level => $self->{loglevel});
+      Log::Any->get_logger;
   };
 
   if ( exists $args->{account_key} )
@@ -527,11 +532,11 @@ sub register
 
   if ( exists $args{mailto} )
   {
-    push @{$obj->{contact}}, $args{mailto};
+    push @{$obj->{contact}}, "mailto:$args{mailto}";
   }
   elsif ( exists $self->{contact}->{mailto} )
   {
-    push @{$obj->{contact}}, $self->{contact}->{mailto};
+    push @{$obj->{contact}}, "mailto:$self->{contact}->{mailto}";
   }
 
   my $msg = _encode_json( $obj );
@@ -790,6 +795,13 @@ sub check_challenge
   }
 }
 
+sub cleanup_challenge
+{
+  my $self = shift;
+  my $challenge = shift;
+  return $challenge->cleanup();
+}
+
 sub sign
 {
   my $self = shift;
