@@ -3,9 +3,7 @@ package Protocol::ACME::Exception;
 use strict;
 use warnings;
 
-use Data::Dumper;
-
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # very simple stringification ... make this
 # more elaborate according to taste
@@ -13,7 +11,9 @@ use overload ('""' => \&stringify);
 sub stringify
 {
     my $self = shift;
-    return ref($self).' error: '.Dumper $self;
+
+    require Data::Dumper;
+    return ref($self).' error: '.Data::Dumper::Dumper($self);
 }
 
 sub new
